@@ -122,6 +122,7 @@ OC.L10N.register(
     "Edit tags" : "Uredi oznake",
     "Move thread" : "Premjesti dretvu",
     "Delete thread" : "Izbriši dretvu",
+    "Delete message" : "Izbriši poruku",
     "More actions" : "Dodatne radnje",
     "Back" : "Natrag",
     "Edit as new message" : "Uredi kao novu poruku",
@@ -267,7 +268,6 @@ OC.L10N.register(
     "Reply to sender only" : "Odgovori pošiljatelju",
     "Mark as unread" : "Označi kao nepročitano",
     "Mark as read" : "Označi kao pročitano",
-    "Delete message" : "Izbriši poruku",
     "Message source" : "Izvor poruke",
     "Could not remove trusted sender {sender}" : "Nije moguće ukloniti pouzdanog pošiljatelja {sender}",
     "No senders are trusted at the moment." : "Trenutno nema pouzdanih pošiljatelja.",
@@ -377,8 +377,6 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Kliknite ovdje ako niste preusmjereni automatski unutar sljedećih nekoliko sekundi.",
     "Redirect" : "Preusmjeri",
     "The link leads to %s" : "Ova poveznica vodi do %s",
-    "Continue to %s" : "Idi do %s",
-    "Uploading attachments …" : "Otpremanje privitaka...",
-    "Sending …" : "Slanje…"
+    "Continue to %s" : "Idi do %s"
 },
 "nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
