@@ -538,8 +538,6 @@ OC.L10N.register(
     "Gmail allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection or Google accounts that use two-factor authentication and app passwords." : "A Gmail lehetővé teszi, hogy a felhasználók IMAP-on keresztül érjék el az e-mailjeiket. Biztonsági okokból ez csak OAuth 2.0-s kapcsolattal lehetséges, vagy olyan Google-fiókkal, amely kétfaktoros hitelesítést és alkalmazásjelszavakat használ.",
     "You have to register a new Client ID for a \"Web application\" in the Google Cloud console. Add the URL {url} as authorized redirect URI." : "Regisztrálnia kell egy új kliensazonosítót egy webalkalmazáshoz a Google Cloud konzolon. Adja meg a {url} webcímet engedélyezett átirányítási címként.",
     "Microsoft integration" : "Microsoft integráció",
-    "Microsoft allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection." : "A Microsoft lehetővé teszi, hogy a felhasználók IMAP-on keresztül érjék el a leveleiket. Biztonsági okokból ez a hozzáférés csak OAuth 2.0-s kapcsolaton lehetséges.",
-    "You have to register a new app in the Microsoft Azure Active Directory portal. Add the URL {url} as redirect URI." : "Regisztrálnia kell egy új alkalmazást a Microsoft Azure Active Directory portálon. Átirányítási URI-nak a következő webcímet adja meg: {url}",
     "Successfully set up anti spam email addresses" : "Sikeresen beállította a levélszemét elhárítási e-mail-címeket",
     "Error saving anti spam email addresses" : "Hiba történt a levélszemét elhárítási e-mail-címek mentése során",
     "Successfully deleted anti spam reporting email" : "Levélszemét bejelentési e-mail-cím sikeresen törölve",
@@ -645,6 +643,8 @@ OC.L10N.register(
     "Redirect" : "Átirányítás",
     "The link leads to %s" : "A hivatkozás ide mutat: %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Ha nem akarja megnyitni azt az oldalt, akkor térjen vissza a <a href=\"%s\">Levelezéshez</a>.",
-    "Continue to %s" : "Folytatás ide: %s"
+    "Continue to %s" : "Folytatás ide: %s",
+    "Microsoft allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection." : "A Microsoft lehetővé teszi, hogy a felhasználók IMAP-on keresztül érjék el a leveleiket. Biztonsági okokból ez a hozzáférés csak OAuth 2.0-s kapcsolaton lehetséges.",
+    "You have to register a new app in the Microsoft Azure Active Directory portal. Add the URL {url} as redirect URI." : "Regisztrálnia kell egy új alkalmazást a Microsoft Azure Active Directory portálon. Átirányítási URI-nak a következő webcímet adja meg: {url}"
 },
 "nplurals=2; plural=(n != 1);");
