@@ -119,7 +119,7 @@ OC.L10N.register(
     "Register as application for mail links" : "Zarejestruj się jako aplikacja do linków pocztowych",
     "Register" : "Zarejestruj się",
     "Data collection consent" : "Zgoda na zbieranie danych",
-    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Zezwól aplikacji na zbieranie danych o Twoich interakcjach. Na podstawie tych danych aplikacja dostosuje się do Twoich preferencji. Dane będą przechowywane tylko lokalnie.",
+    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Zezwalaj aplikacji na zbieranie danych o Twoich interakcjach. Na podstawie tych danych aplikacja dostosuje się do Twoich preferencji. Dane będą przechowywane tylko lokalnie.",
     "Trusted senders" : "Zaufani nadawcy",
     "Manage S/MIME certificates" : "Zarządzaj certyfikatami S/MIME",
     "Looking for a way to encrypt your emails?" : "Szukasz sposobu na szyfrowanie wiadomości e-mail?",
@@ -500,8 +500,6 @@ OC.L10N.register(
     "Gmail allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection or Google accounts that use two-factor authentication and app passwords." : "Gmail umożliwia użytkownikom dostęp do poczty e-mail za pośrednictwem protokołu IMAP. Ze względów bezpieczeństwa dostęp ten jest możliwy tylko za pomocą połączenia OAuth 2.0 lub kont Google korzystających z uwierzytelniania dwuskładnikowego i haseł do aplikacji.",
     "You have to register a new Client ID for a \"Web application\" in the Google Cloud console. Add the URL {url} as authorized redirect URI." : "Musisz zarejestrować nowy ID klienta dla \"Aplikacji internetowej\" w konsoli Google Cloud. Dodaj adres URL {url} jako identyfikator URI autoryzowanego przekierowania.",
     "Microsoft integration" : "Integracja Microsoft",
-    "Microsoft allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection." : "Firma Microsoft umożliwia użytkownikom dostęp do poczty e-mail za pośrednictwem protokołu IMAP. Ze względów bezpieczeństwa dostęp ten jest możliwy tylko przy połączeniu OAuth 2.0.",
-    "You have to register a new app in the Microsoft Azure Active Directory portal. Add the URL {url} as redirect URI." : "Musisz zarejestrować nową aplikację w portalu Microsoft Azure Active Directory. Dodaj adres URL {url} jako URI przekierowania.",
     "Successfully set up anti spam email addresses" : "Pomyślnie skonfigurowane antyspamowe adresy e-mail",
     "Error saving anti spam email addresses" : "Błąd podczas zapisywania antyspamowych adresów e-mail",
     "Successfully deleted anti spam reporting email" : "Pomyślnie usunięto e-mail z raportami antyspamowymi",
@@ -592,6 +590,8 @@ OC.L10N.register(
     "Redirect" : "Przekieruj",
     "The link leads to %s" : "Link prowadzi do %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Jeśli nie chcesz odwiedzić tej strony, możesz powrócić do <a href=\"%s\">Poczty</a>.",
-    "Continue to %s" : "Kontynuuj do %s"
+    "Continue to %s" : "Kontynuuj do %s",
+    "Microsoft allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection." : "Firma Microsoft umożliwia użytkownikom dostęp do poczty e-mail za pośrednictwem protokołu IMAP. Ze względów bezpieczeństwa dostęp ten jest możliwy tylko przy połączeniu OAuth 2.0.",
+    "You have to register a new app in the Microsoft Azure Active Directory portal. Add the URL {url} as redirect URI." : "Musisz zarejestrować nową aplikację w portalu Microsoft Azure Active Directory. Dodaj adres URL {url} jako URI przekierowania."
 },
 "nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
