@@ -128,7 +128,6 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Klikoni këtu nëse nuk ridrejtoheni automatikisht brenda disa sekondave",
     "Redirect" : "Ridrejtoje",
     "The link leads to %s" : "Lidhja shpie te %s",
-    "Continue to %s" : "Vazhdo te %s",
-    "Sending …" : "Po dërgohet …"
+    "Continue to %s" : "Vazhdo te %s"
 },
 "nplurals=2; plural=(n != 1);");
