@@ -230,7 +230,9 @@ OC.L10N.register(
     "Unsnooze" : "Актуальне",
     "Move thread" : "Пересунути ланцюг",
     "Archive thread" : "Архівувати ланцюг",
+    "Archive message" : "Архівувати повідомлення",
     "Delete thread" : "Вилучити ланцюг",
+    "Delete message" : "Вилучити повідомлення",
     "More actions" : "Більше дій",
     "Back" : "Назад",
     "Set custom snooze" : "Налаштувати, на скільки відкладати",
@@ -480,8 +482,6 @@ OC.L10N.register(
     "Mark as favorite" : "Позначити зірочкою",
     "Mark as unread" : "Позначити не прочитаним",
     "Mark as read" : "Позначити прочитаним",
-    "Archive message" : "Архівувати повідомлення",
-    "Delete message" : "Вилучити повідомлення",
     "Message source" : "Джерело повідомлення",
     "Unsubscribe via link" : "Відписатися через посилання",
     "Send unsubscribe email" : "Надіслати електронний лист щодо відписування",
@@ -568,8 +568,6 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Натисніть тут, якщо вас не буде автоматично перенаправлено протягом наступних кількох секунд.",
     "Redirect" : "Перенаправлення",
     "The link leads to %s" : "Посилання веде до %s",
-    "Continue to %s" : "Перейти до %s",
-    "Uploading attachments …" : "Завантаження вкладень...",
-    "Sending …" : "Надсилання..."
+    "Continue to %s" : "Перейти до %s"
 },
 "nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
