@@ -9,6 +9,10 @@ declare(strict_types=1);
 
 namespace OCA\Mail\Dashboard;
 
+use OCA\Mail\Service\Search\Flag;
+use OCA\Mail\Service\Search\GlobalSearchQuery;
+use OCA\Mail\Service\Search\SearchQuery;
+
 class ImportantMailWidget extends MailWidget {
 	/**
 	 * @inheritDoc
@@ -24,10 +28,10 @@ class ImportantMailWidget extends MailWidget {
 		return $this->l10n->t('Important mail');
 	}
 
-	/**
-	 * @inheritDoc
-	 */
-	public function getSearchFilter(): string {
-		return 'is:important';
+	public function getSearchQuery(string $userId): SearchQuery {
+		$query = new GlobalSearchQuery();
+		$query->addFlag(Flag::is(Flag::IMPORTANT));
+		$query->setExcludeMailboxIds($this->getMailboxIdsToExclude($userId));
+		return $query;
 	}
 }
